@@ -66,6 +66,7 @@ class SQLParams(object):
 		escape_char: Union[str, bool, None] = None,
 		expand_tuples: Optional[bool] = None,
 		strip_comments: Union[Sequence[Union[str, Tuple[str, str]]], bool, None] = None,
+		allow_out_quotes: Optional[bool] = None,
 	) -> None:
 		"""
 		Instantiates the :class:`.SQLParams` instance.
@@ -89,7 +90,7 @@ class SQLParams(object):
 		*out_style* is a named style, do not expand tuples by default (``False``).
 
 		.. NOTE:: Empty tuples will be safely expanded to ``(NULL)`` to prevent SQL
-		   syntax errors,
+		   syntax errors.
 
 		*strip_comments* (:class:`~collections.abc.Sequence`, :class:`bool`, or
 		``None``) whether to strip out comments and what style of comments to
@@ -103,11 +104,14 @@ class SQLParams(object):
 		``DEFAULT_COMMENTS`` will be used (``"--"`` and ``("/*", "*/")`` styles).
 		Default is ``None`` to not remove comments.
 
+		*allow_out_quotes* (:class:`bool` or ``None``) is whether to quote the out
+		parameters when *out_style* supports it. Default is ``None`` for ``False``.
+
 		The following parameter styles are supported by both *in_style* and
 		*out_style*:
 
 		-	For all named styles the parameter keys must be valid `Python identifiers`_.
-			They cannot start with a digit. This is to help preven incorrectly
+			They cannot start with a digit. This is to help prevent incorrectly
 			matching common strings such as date-times.
 
 			Named styles:
@@ -123,6 +127,14 @@ class SQLParams(object):
 
 				.. NOTE:: This is not defined by `PEP 249`_.
 
+			-	"named_oracle" indicates parameters will use the named style supported
+				by Oracle which allows for case-insensitive unquoted parameters and
+				case-sensitive quoted parameters::
+
+					... WHERE name = :name OR name = :"name"
+
+				.. NOTE:: This is not defined by `PEP 249`_.
+
 			-	"pyformat" indicates parameters will use the named Python extended
 				format style::
 
@@ -212,6 +224,7 @@ class SQLParams(object):
 			in_style=in_style,
 			out_obj=out_obj,
 			out_style=out_style,
+			allow_out_quotes=bool(allow_out_quotes),
 		)
 		"""
 		*__converter* (:class:`._converting.Converter`) is the parameter converter
@@ -292,6 +305,7 @@ class SQLParams(object):
 		in_style: str,
 		out_obj: _styles.Style,
 		out_style: str,
+		allow_out_quotes: bool,
 	) -> _converting.Converter:
 		"""
 		Create the parameter style converter.
@@ -357,6 +371,7 @@ class SQLParams(object):
 			in_regex=in_regex,
 			in_style=in_obj,
 			out_style=out_obj,
+			allow_out_quotes=allow_out_quotes
 		)
 		return converter
 
