@@ -167,6 +167,247 @@ class Test(unittest.TestCase):
 		self.assertEqual(sql, dest_sql)
 		self.assertEqual(many_params, dest_params)
 
+	def test_1_named_oracle_1_to_qmark_1_no_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :name
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :ID OR name = :Name AND race = :race;
+		"""
+		src_params = {'id': 4, 'NAME': "Fili", 'Race': "dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [src_params[__key] for __key in ['id', 'NAME', 'Race']]
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_1_to_qmark_2_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :"race";
+		"""
+		src_params = {'"ID"': 4, '"Name"': "Fili", '"race"': "dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [src_params[__key] for __key in ['"ID"', '"Name"', '"race"']]
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_1_to_qmark_3_mixed(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :race;
+		"""
+		src_params = {'id': 4, '"Name"': "Fili", '"RACE"': "dwarf"}
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [src_params[__key] for __key in ['id', '"Name"', '"RACE"']]
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_1_named_oracle_2_to_qmark_many_1_no_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :name
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		# - WARNING: Only the first row is scanned for the in-parameter names. All
+		#   subsequent rows must have the exact same in-parameter names.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :ID OR name = :Name AND race = :race;
+		"""
+		src_params = [
+			{'id': 7, 'NAME': "Ori", 'Race': "dwarf"},
+			{'id': 5, 'NAME': "Dori", 'Race': "dwarf"},
+			{'id': 10, 'NAME': "Bifur", 'Race': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [
+			[__row[__key] for __key in ['id', 'NAME', 'Race']]
+			for __row in src_params
+		]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
+	def test_1_named_oracle_2_to_qmark_many_2_quotes(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :"race";
+		"""
+		src_params = [
+			{'"ID"': 7, '"Name"': "Ori", '"race"': "dwarf"},
+			{'"ID"': 5, '"Name"': "Dori", '"race"': "dwarf"},
+			{'"ID"': 10, '"Name"': "Bifur", '"race"': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [
+			[__row[__key] for __key in ['"ID"', '"Name"', '"race"']]
+			for __row in src_params
+		]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
+	def test_1_named_oracle_2_to_qmark_3_many_mixed(self):
+		"""
+		Test converting from::
+
+			... WHERE name = :"name"
+
+		to::
+
+			... WHERE name = ?
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('named_oracle', 'qmark')
+
+		# Source SQL and params.
+		# - WARNING: Only the first row is scanned for the in-parameter names. All
+		#   subsequent rows must have the exact same in-parameter names.
+		src_sql = """
+			SELECT *
+			FROM users
+			WHERE id = :"ID" OR name = :"Name" AND race = :race;
+		"""
+		src_params = [
+			{'id': 7, '"Name"': "Ori", '"RACE"': "dwarf"},
+			{'id': 5, '"Name"': "Dori", '"RACE"': "dwarf"},
+			{'id': 10, '"Name"': "Bifur", '"RACE"': "dwarf"},
+		]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT *
+			FROM users
+			WHERE id = ? OR name = ? AND race = ?;
+		"""
+		dest_params = [
+			[__row[__key] for __key in ['id', '"Name"', '"RACE"']]
+			for __row in src_params
+		]
+
+		# Format SQL with params.
+		sql, many_params = query.formatmany(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(many_params, dest_params)
+
 	def test_1_pyformat_to_format(self):
 		"""
 		Test converting from::
@@ -464,7 +705,12 @@ class Test(unittest.TestCase):
 			FROM users
 			WHERE id = ? OR name = ? OR altid = ? OR altname = ?;
 		"""
-		dest_params = [src_params['id'], src_params['name'], src_params['id'], src_params['name']]
+		dest_params = [
+			src_params['id'],
+			src_params['name'],
+			src_params['id'],
+			src_params['name'],
+		]
 
 		# Format SQL with params.
 		sql, params = query.format(src_sql, src_params)
@@ -498,7 +744,10 @@ class Test(unittest.TestCase):
 			FROM users
 			WHERE id = ? OR name = ? OR altid = ? OR altname = ?;
 		"""
-		dest_params = [[__row['id'], __row['name'], __row['id'], __row['name']] for __row in src_params]
+		dest_params = [
+			[__row['id'], __row['name'], __row['id'], __row['name']]
+			for __row in src_params
+		]
 
 		# Format SQL with params.
 		sql, many_params = query.formatmany(src_sql, src_params)
